{% extends "admin/cms/page/plugin_change_form.html" %}
{% load adminmedia %}

{% block fieldsets %}
{% for fieldset in adminform %}
	{% include "admin/includes/fieldset.html" %}
{% endfor %}
<script type="text/javascript">
(function namespacing(jQuery) {
	jQuery(document).ready(function ($) {
		// initialize security patch
		window.CMS.API.Security.csrf();
	});
})(window.CMS.$)
</script>
<style>
    div.body label {display:none}
</style>
{% endblock %}
