/*
Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.plugins.setLang('specialchar','pt-br',{euro:'Euro',lsquo:'Aspas simples esquerda',rsquo:'Aspas simples direita',ldquo:'Aspas duplas esquerda',rdquo:'Aspas duplas direita',ndash:'Traço',mdash:'Travessão',iexcl:'Ponto de exclamação invertido',cent:'Cent',pound:'Cerquilha',curren:'Dinheiro',yen:'Yen',brvbar:'Bara interrompida',sect:'Símbolo de Parágrafo',uml:'Trema',copy:'Direito de Cópia',ordf:'Indicador ordinal feminino',laquo:'Aspas duplas angulares esquerda',not:'Negação',reg:'Marca Registrada',macr:'Mácron',deg:'Grau',sup2:'2 Superscrito',sup3:'3 Superscrito',acute:'Acento agudo',micro:'Micro',para:'Pé de mosca',middot:'Ponto mediano',cedil:'Cedilha',sup1:'1 Superscrito',ordm:'Indicador ordinal masculino',raquo:'Aspas duplas angulares direita',frac14:'Um quarto',frac12:'Um meio',frac34:'Três quartos',iquest:'Interrogação invertida',Agrave:'A maiúsculo com acento grave',Aacute:'A maiúsculo com acento agudo',Acirc:'A maiúsculo com acento circunflexo',Atilde:'A maiúsculo com til',Auml:'A maiúsculo com trema',Aring:'A maiúsculo com anel acima',AElig:'Æ maiúsculo',Ccedil:'Ç maiúlculo',Egrave:'E maiúsculo com acento grave',Eacute:'E maiúsculo com acento agudo',Ecirc:'E maiúsculo com acento circumflexo',Euml:'E maiúsculo com trema',Igrave:'I maiúsculo com acento grave',Iacute:'I maiúsculo com acento agudo',Icirc:'I maiúsculo com acento circunflexo',Iuml:'I maiúsculo com crase',ETH:'Eth maiúsculo',Ntilde:'N maiúsculo com til',Ograve:'O maiúsculo com acento grave',Oacute:'O maiúsculo com acento agudo',Ocirc:'O maiúsculo com acento circunflexo',Otilde:'O maiúsculo com til',Ouml:'O maiúsculo com trema',times:'Multiplicação',Oslash:'Diâmetro',Ugrave:'U maiúsculo com acento grave',Uacute:'U maiúsculo com acento agudo',Ucirc:'U maiúsculo com acento circunflexo',Uuml:'U maiúsculo com trema',Yacute:'Y maiúsculo com acento agudo',THORN:'Thorn maiúsculo',szlig:'Eszett minúsculo',agrave:'a minúsculo com acento grave',aacute:'a minúsculo com acento agudo',acirc:'a minúsculo com acento circunflexo',atilde:'a minúsculo com til',auml:'a minúsculo com trema',aring:'a minúsculo com anel acima',aelig:'æ minúsculo',ccedil:'ç minúsculo',egrave:'e minúsculo com acento grave',eacute:'e minúsculo com acento agudo',ecirc:'e minúsculo com acento circunflexo',euml:'e minúsculo com trema',igrave:'i minúsculo com acento grave',iacute:'i minúsculo com acento agudo',icirc:'i minúsculo com acento circunflexo',iuml:'i minúsculo com trema',eth:'eth minúsculo',ntilde:'n minúsculo com til',ograve:'o minúsculo com acento grave',oacute:'o minúsculo com acento agudo',ocirc:'o minúsculo com acento circunflexo',otilde:'o minúsculo com til',ouml:'o minúsculo com trema',divide:'Divisão',oslash:'o minúsculo com cortado ou diâmetro',ugrave:'u minúsculo com acento grave',uacute:'u minúsculo com acento agudo',ucirc:'u minúsculo com acento circunflexo',uuml:'u minúsculo com trema',yacute:'y minúsculo com acento agudo',thorn:'thorn minúsculo',yuml:'y minúsculo com trema',OElig:'Ligação tipográfica OE maiúscula',oelig:'Ligação tipográfica oe minúscula',372:'W maiúsculo com acento circunflexo',374:'Y maiúsculo com acento circunflexo',373:'w minúsculo com acento circunflexo',375:'y minúsculo com acento circunflexo',sbquo:'Aspas simples inferior direita',8219:'Aspas simples superior esquerda',bdquo:'Aspas duplas inferior direita',hellip:'Reticências',trade:'Trade mark',9658:'Ponta de seta preta para direita',bull:'Ponto lista',rarr:'Seta para direita',rArr:'Seta dupla para direita',hArr:'Seta dupla direita e esquerda',diams:'Ouros',asymp:'Aproximadamente'});
