/*
Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.plugins.setLang('specialchar','nl',{euro:'Euro-teken',lsquo:'Linker enkel aanhalingsteken',rsquo:'Rechter enkel aanhalingsteken',ldquo:'Linker dubbel aanhalingsteken',rdquo:'Rechter dubbel aanhalingsteken',ndash:'En dash',mdash:'Em dash',iexcl:'Omgekeerd uitroepteken',cent:'Cent-teken',pound:'Pond-teken',curren:'Valuta-teken',yen:'Yen-teken',brvbar:'Gebroken streep',sect:'Paragraaf-teken',uml:'Trema',copy:'Copyright-teken',ordf:'Vrouwelijk ordinaal',laquo:'Linker guillemet',not:'Ongelijk-teken',reg:'Geregistreerd handelsmerk-teken',macr:'Macron',deg:'Graden-teken',sup2:'Superscript twee',sup3:'Superscript drie',acute:'Accent aigu',micro:'Mico-teken',para:'Alinea-teken',middot:'Halfhoge punt',cedil:'Cedille',sup1:'Superscript een',ordm:'Mannelijk ordinaal',raquo:'Rechter guillemet',frac14:'Breuk kwart',frac12:'Breuk half',frac34:'Breuk driekwart',iquest:'Omgekeerd vraagteken',Agrave:'Latijnse hoofdletter A met een accent grave',Aacute:'Latijnse hoofdletter A met een accent aigu',Acirc:'Latijnse hoofdletter A met een circonflexe',Atilde:'Latijnse hoofdletter A met een tilde',Auml:'Latijnse hoofdletter A met een trema',Aring:'Latijnse hoofdletter A met een corona',AElig:'Latijnse hoofdletter Æ',Ccedil:'Latijnse hoofdletter C met een cedille',Egrave:'Latijnse hoofdletter E met een accent grave',Eacute:'Latijnse hoofdletter E met een accent aigu',Ecirc:'Latijnse hoofdletter E met een circonflexe',Euml:'Latijnse hoofdletter E met een trema',Igrave:'Latijnse hoofdletter I met een accent grave',Iacute:'Latijnse hoofdletter I met een accent aigu',Icirc:'Latijnse hoofdletter I met een circonflexe',Iuml:'Latijnse hoofdletter I met een trema',ETH:'Latijnse hoofdletter Eth',Ntilde:'Latijnse hoofdletter N met een tilde',Ograve:'Latijnse hoofdletter O met een accent grave',Oacute:'Latijnse hoofdletter O met een accent aigu',Ocirc:'Latijnse hoofdletter O met een circonflexe',Otilde:'Latijnse hoofdletter O met een tilde',Ouml:'Latijnse hoofdletter O met een trema',times:'Maal-teken',Oslash:'Latijnse hoofdletter O met een schuine streep',Ugrave:'Latijnse hoofdletter U met een accent grave',Uacute:'Latijnse hoofdletter U met een accent aigu',Ucirc:'Latijnse hoofdletter U met een circonflexe',Uuml:'Latijnse hoofdletter U met een trema',Yacute:'Latijnse hoofdletter Y met een accent aigu',THORN:'Latijnse hoofdletter Thorn',szlig:'Latijnse kleine ringel-s',agrave:'Latijnse kleine letter a met een accent grave',aacute:'Latijnse kleine letter a met een accent aigu',acirc:'Latijnse kleine letter a met een circonflexe',atilde:'Latijnse kleine letter a met een tilde',auml:'Latijnse kleine letter a met een trema',aring:'Latijnse kleine letter a met een corona',aelig:'Latijnse kleine letter æ',ccedil:'Latijnse kleine letter c met een cedille',egrave:'Latijnse kleine letter e met een accent grave',eacute:'Latijnse kleine letter e met een accent aigu',ecirc:'Latijnse kleine letter e met een circonflexe',euml:'Latijnse kleine letter e met een trema',igrave:'Latijnse kleine letter i met een accent grave',iacute:'Latijnse kleine letter i met een accent aigu',icirc:'Latijnse kleine letter i met een circonflexe',iuml:'Latijnse kleine letter i met een trema',eth:'Latijnse kleine letter eth',ntilde:'Latijnse kleine letter n met een tilde',ograve:'Latijnse kleine letter o met een accent grave',oacute:'Latijnse kleine letter o met een accent aigu',ocirc:'Latijnse kleine letter o met een circonflexe',otilde:'Latijnse kleine letter o met een tilde',ouml:'Latijnse kleine letter o met een trema',divide:'Deel-teken',oslash:'Latijnse kleine letter o met een schuine streep',ugrave:'Latijnse kleine letter u met een accent grave',uacute:'Latijnse kleine letter u met een accent aigu',ucirc:'Latijnse kleine letter u met een circonflexe',uuml:'Latijnse kleine letter u met een trema',yacute:'Latijnse kleine letter y met een accent aigu',thorn:'Latijnse kleine letter thorn',yuml:'Latijnse kleine letter y met een trema',OElig:'Latijnse hoofdletter Œ',oelig:'Latijnse kleine letter œ',372:'Latijnse hoofdletter W met een circonflexe',374:'Latijnse hoofdletter Y met een circonflexe',373:'Latijnse kleine letter w met een circonflexe',375:'Latijnse kleine letter y met een circonflexe',sbquo:'Lage enkele aanhalingsteken',8219:'Hoge omgekeerde enkele aanhalingsteken',bdquo:'Lage dubbele aanhalingsteken',hellip:'Beletselteken',trade:'Trademark-teken',9658:'Zwarte driehoek naar rechts',bull:'Bullet',rarr:'Pijl naar rechts',rArr:'Dubbele pijl naar rechts',hArr:'Dubbele pijl naar links',diams:'Zwart ruitje',asymp:'Benaderingsteken'});
