/*
Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.plugins.setLang('specialchar','ug',{euro:'ياۋرو بەلگىسى',lsquo:'يالاڭ پەش سول',rsquo:'يالاڭ پەش ئوڭ',ldquo:'قوش پەش سول',rdquo:'قوش پەش ئوڭ',ndash:'سىزىقچە',mdash:'سىزىق',iexcl:'ئۈندەش',cent:'تىيىن بەلگىسى',pound:'فوند ستېرلىڭ',curren:'پۇل بەلگىسى',yen:'ياپونىيە يىنى',brvbar:'ئۈزۈك بالداق',sect:'پاراگراف بەلگىسى',uml:'تاۋۇش ئايرىش بەلگىسى',copy:'نەشر ھوقۇقى بەلگىسى',ordf:'Feminine ordinal indicator',laquo:'قوش تىرناق سول',not:'غەيرى بەلگە',reg:'خەتلەتكەن تاۋار ماركىسى',macr:'سوزۇش بەلگىسى',deg:'گىرادۇس بەلگىسى',sup2:'يۇقىرى ئىندېكىس 2',sup3:'يۇقىرى ئىندېكىس 3',acute:'ئۇرغۇ بەلگىسى',micro:'Micro sign',para:'ئابزاس بەلگىسى',middot:'ئوتتۇرا چېكىت',cedil:'ئاستىغا قوشۇلىدىغان بەلگە',sup1:'يۇقىرى ئىندېكىس 1',ordm:'Masculine ordinal indicator',raquo:'قوش تىرناق ئوڭ',frac14:'ئاددىي كەسىر تۆتتىن بىر',frac12:'ئاددىي كەسىر ئىككىدىن بىر',frac34:'ئاددىي كەسىر ئۈچتىن تۆرت',iquest:'Inverted question mark',Agrave:'Latin capital letter A with grave accent',Aacute:'Latin capital letter A with acute accent',Acirc:'Latin capital letter A with circumflex',Atilde:'Latin capital letter A with tilde',Auml:'Latin capital letter A with diaeresis',Aring:'Latin capital letter A with ring above',AElig:'Latin Capital letter Æ',Ccedil:'Latin capital letter C with cedilla',Egrave:'Latin capital letter E with grave accent',Eacute:'Latin capital letter E with acute accent',Ecirc:'Latin capital letter E with circumflex',Euml:'Latin capital letter E with diaeresis',Igrave:'Latin capital letter I with grave accent',Iacute:'Latin capital letter I with acute accent',Icirc:'Latin capital letter I with circumflex',Iuml:'Latin capital letter I with diaeresis',ETH:'Latin capital letter Eth',Ntilde:'Latin capital letter N with tilde',Ograve:'قوش پەش ئوڭ',Oacute:'Latin capital letter O with acute accent',Ocirc:'Latin capital letter O with circumflex',Otilde:'Latin capital letter O with tilde',Ouml:'Latin capital letter O with diaeresis',times:'Multiplication sign',Oslash:'Latin capital letter O with stroke',Ugrave:'Latin capital letter U with grave accent',Uacute:'Latin capital letter U with acute accent',Ucirc:'Latin capital letter U with circumflex',Uuml:'Latin capital letter U with diaeresis',Yacute:'Latin capital letter Y with acute accent',THORN:'Latin capital letter Thorn',szlig:'Latin small letter sharp s',agrave:'Latin small letter a with grave accent',aacute:'Latin small letter a with acute accent',acirc:'Latin small letter a with circumflex',atilde:'Latin small letter a with tilde',auml:'Latin small letter a with diaeresis',aring:'Latin small letter a with ring above',aelig:'Latin small letter æ',ccedil:'Latin small letter c with cedilla',egrave:'Latin small letter e with grave accent',eacute:'Latin small letter e with acute accent',ecirc:'Latin small letter e with circumflex',euml:'Latin small letter e with diaeresis',igrave:'Latin small letter i with grave accent',iacute:'Latin small letter i with acute accent',icirc:'Latin small letter i with circumflex',iuml:'Latin small letter i with diaeresis',eth:'Latin small letter eth',ntilde:'تىك موللاق سوئال بەلگىسى',ograve:'Latin small letter o with grave accent',oacute:'Latin small letter o with acute accent',ocirc:'Latin small letter o with circumflex',otilde:'Latin small letter o with tilde',ouml:'Latin small letter o with diaeresis',divide:'Division sign',oslash:'Latin small letter o with stroke',ugrave:'Latin small letter u with grave accent',uacute:'Latin small letter u with acute accent',ucirc:'Latin small letter u with circumflex',uuml:'Latin small letter u with diaeresis',yacute:'Latin small letter y with acute accent',thorn:'Latin small letter thorn',yuml:'Latin small letter y with diaeresis',OElig:'Latin capital ligature OE',oelig:'Latin small ligature oe',372:'Latin capital letter W with circumflex',374:'Latin capital letter Y with circumflex',373:'Latin small letter w with circumflex',375:'Latin small letter y with circumflex',sbquo:'Single low-9 quotation mark',8219:'Single high-reversed-9 quotation mark',bdquo:'Double low-9 quotation mark',hellip:'Horizontal ellipsis',trade:'Trade mark sign',9658:'Black right-pointing pointer',bull:'Bullet',rarr:'ئوڭ يا ئوق',rArr:'ئوڭ قوش سىزىق يا ئوق',hArr:'ئوڭ سول قوش سىزىق يا ئوق',diams:'ئۇيۇل غىچ',asymp:'تەخمىنەن تەڭ'});
